@@ -5,7 +5,7 @@
 import os
 
 try:
-    fgurl = os.environ['FG_URL'].rsplit(":", 1)[0]
+    fgurl = os.environ["FG_URL"].rsplit(":", 1)[0]
 except:
     fgurl = "https://beta.fastgenomics.org"
 DOCSURL = fgurl + "/docs/"
